.. _whatsnew-index:

########################
 What's New in neo-mamba
########################


This chapter describes the most important changes between the neo-mamba versions. For a detailed list of all changes see the CHANGELOG.

.. toctree::
   :maxdepth: 2

   0.1.rst
   0.2.rst
   0.3.rst
   0.4.rst
   0.5.rst
   0.6.rst
   0.7.rst
   0.8.rst
   0.9.rst
   0.9.1.rst
   0.9.2.rst
   0.9.3.rst